@@ -30,9 +30,13 @@ class Extractor(object):
         self.max_recursion = int(kwargs.get('max_recursion'))
         self.max_http_retries = int(kwargs.get('max_http_retries'))
 
+        self.workplace_url = kwargs.get('workplace_url')
         self.graph_url = kwargs.get('graph_url')
         self.scim_url = kwargs.get('scim_url')
 
+        self.comment_weight = kwargs.get('comment_weight')
+        self.reaction_weight = kwargs.get('reaction_weight')
+
         self.update_task_progress_func = kwargs.get('update_task_progress_func', None)
         self.celery_task = kwargs.get('celery_task', None)
 
@@ -136,14 +140,12 @@ class Extractor(object):
                     if resp.status in [400, 401, 404]:
                         logging.warning(f'Response returned {resp.status} for {url}.')
                         data = pd.DataFrame({'Errors': resp.status}, index=[0])
+                        print('400')
                         return data
                     elif resp.status in [500]:
                         logging.error(f'Error 500 when calling {url}')
                         raise Exception
                     else:
-                        #if api == 'SCIM':
-                        #    content_type = 'text/javascript'
-                        #elif api == 'GRAPH':
                         content_type = 'application/json'
 
                         return await resp.json(content_type=content_type)
@@ -154,7 +156,7 @@ class Extractor(object):
                 logging.warning(f' {tries} of {max_retries}')
 
         if tries == max_retries:
-            #raise TimeoutError('Too many retries')
+            # raise TimeoutError('Too many retries')
             logging.critical(f'Response returned ERROR 500 for {url}.')
 
     @staticmethod
